# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2 import (
    FeedItemSetStringFilterTypeEnum as google___ads___googleads___v6___enums___feed_item_set_string_filter_type_pb2___FeedItemSetStringFilterTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DynamicLocationSetFilter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    labels: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    @property
    def business_name_filter(self) -> type___BusinessNameFilter: ...
    def __init__(
        self,
        *,
        labels: typing___Optional[typing___Iterable[typing___Text]] = None,
        business_name_filter: typing___Optional[type___BusinessNameFilter] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "business_name_filter", b"business_name_filter"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "business_name_filter", b"business_name_filter", "labels", b"labels"
        ],
    ) -> None: ...

type___DynamicLocationSetFilter = DynamicLocationSetFilter

class BusinessNameFilter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    business_name: typing___Text = ...
    filter_type: google___ads___googleads___v6___enums___feed_item_set_string_filter_type_pb2___FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterTypeValue = ...
    def __init__(
        self,
        *,
        business_name: typing___Optional[typing___Text] = None,
        filter_type: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_set_string_filter_type_pb2___FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "business_name", b"business_name", "filter_type", b"filter_type"
        ],
    ) -> None: ...

type___BusinessNameFilter = BusinessNameFilter

class DynamicAffiliateLocationSetFilter(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    chain_ids: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        builtin___int
    ] = ...
    def __init__(
        self, *, chain_ids: typing___Optional[typing___Iterable[builtin___int]] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["chain_ids", b"chain_ids"]
    ) -> None: ...

type___DynamicAffiliateLocationSetFilter = DynamicAffiliateLocationSetFilter



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.change_status_operation_pb2 import (
    ChangeStatusOperationEnum as google___ads___googleads___v3___enums___change_status_operation_pb2___ChangeStatusOperationEnum,
)
from google.ads.google_ads.v3.proto.enums.change_status_resource_type_pb2 import (
    ChangeStatusResourceTypeEnum as google___ads___googleads___v3___enums___change_status_resource_type_pb2___ChangeStatusResourceTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeStatus(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    resource_type: google___ads___googleads___v3___enums___change_status_resource_type_pb2___ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue = ...
    resource_status: google___ads___googleads___v3___enums___change_status_operation_pb2___ChangeStatusOperationEnum.ChangeStatusOperationValue = ...
    @property
    def last_change_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group_ad(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def feed_item(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group_feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign_feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group_bid_modifier(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        last_change_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        resource_type: typing___Optional[
            google___ads___googleads___v3___enums___change_status_resource_type_pb2___ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue
        ] = None,
        campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        resource_status: typing___Optional[
            google___ads___googleads___v3___enums___change_status_operation_pb2___ChangeStatusOperationEnum.ChangeStatusOperationValue
        ] = None,
        ad_group_ad: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        ad_group_criterion: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        campaign_criterion: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        feed: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        feed_item: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        ad_group_feed: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        campaign_feed: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        ad_group_bid_modifier: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_feed",
            b"ad_group_feed",
            "campaign",
            b"campaign",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_feed",
            b"campaign_feed",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "last_change_date_time",
            b"last_change_date_time",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_feed",
            b"ad_group_feed",
            "campaign",
            b"campaign",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_feed",
            b"campaign_feed",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "last_change_date_time",
            b"last_change_date_time",
            "resource_name",
            b"resource_name",
            "resource_status",
            b"resource_status",
            "resource_type",
            b"resource_type",
        ],
    ) -> None: ...

type___ChangeStatus = ChangeStatus



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MultiplierErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MultiplierErrorValue = typing___NewType("MultiplierErrorValue", builtin___int)
    type___MultiplierErrorValue = MultiplierErrorValue
    MultiplierError: _MultiplierError
    class _MultiplierError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MultiplierErrorEnum.MultiplierErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 0)
        UNKNOWN = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 1)
        MULTIPLIER_TOO_HIGH = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 2)
        MULTIPLIER_TOO_LOW = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 3)
        TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 4
        )
        MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 5
        )
        MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 6
        )
        NO_MULTIPLIER_SPECIFIED = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 7
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 8
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 9
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 10
        )
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 11
        )
        BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 12
        )
        MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = typing___cast(
            MultiplierErrorEnum.MultiplierErrorValue, 13
        )
    UNSPECIFIED = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 0)
    UNKNOWN = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 1)
    MULTIPLIER_TOO_HIGH = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 2)
    MULTIPLIER_TOO_LOW = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 3)
    TOO_MANY_FRACTIONAL_DIGITS = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 4
    )
    MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 5
    )
    MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 6
    )
    NO_MULTIPLIER_SPECIFIED = typing___cast(MultiplierErrorEnum.MultiplierErrorValue, 7)
    MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 8
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 9
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 10
    )
    MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 11
    )
    BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 12
    )
    MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH = typing___cast(
        MultiplierErrorEnum.MultiplierErrorValue, 13
    )
    type___MultiplierError = MultiplierError
    def __init__(self,) -> None: ...

type___MultiplierErrorEnum = MultiplierErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ResponseContentTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ResponseContentTypeValue = typing___NewType(
        "ResponseContentTypeValue", builtin___int
    )
    type___ResponseContentTypeValue = ResponseContentTypeValue
    ResponseContentType: _ResponseContentType
    class _ResponseContentType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ResponseContentTypeEnum.ResponseContentTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ResponseContentTypeEnum.ResponseContentTypeValue, 0)
        RESOURCE_NAME_ONLY = typing___cast(
            ResponseContentTypeEnum.ResponseContentTypeValue, 1
        )
        MUTABLE_RESOURCE = typing___cast(
            ResponseContentTypeEnum.ResponseContentTypeValue, 2
        )
    UNSPECIFIED = typing___cast(ResponseContentTypeEnum.ResponseContentTypeValue, 0)
    RESOURCE_NAME_ONLY = typing___cast(
        ResponseContentTypeEnum.ResponseContentTypeValue, 1
    )
    MUTABLE_RESOURCE = typing___cast(
        ResponseContentTypeEnum.ResponseContentTypeValue, 2
    )
    type___ResponseContentType = ResponseContentType
    def __init__(self,) -> None: ...

type___ResponseContentTypeEnum = ResponseContentTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountLinkStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AccountLinkStatusValue = typing___NewType("AccountLinkStatusValue", builtin___int)
    type___AccountLinkStatusValue = AccountLinkStatusValue
    AccountLinkStatus: _AccountLinkStatus
    class _AccountLinkStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AccountLinkStatusEnum.AccountLinkStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 0)
        UNKNOWN = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 1)
        ENABLED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 2)
        REMOVED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 3)
        REQUESTED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 4)
        PENDING_APPROVAL = typing___cast(
            AccountLinkStatusEnum.AccountLinkStatusValue, 5
        )
    UNSPECIFIED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 0)
    UNKNOWN = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 1)
    ENABLED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 2)
    REMOVED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 3)
    REQUESTED = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 4)
    PENDING_APPROVAL = typing___cast(AccountLinkStatusEnum.AccountLinkStatusValue, 5)
    type___AccountLinkStatus = AccountLinkStatus
    def __init__(self,) -> None: ...

type___AccountLinkStatusEnum = AccountLinkStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BytesValue as google___protobuf___wrappers_pb2___BytesValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v4___enums___mime_type_pb2___MimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class YoutubeVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def youtube_video_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        youtube_video_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "youtube_video_id", b"youtube_video_id"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "youtube_video_id", b"youtube_video_id"
        ],
    ) -> None: ...

type___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...
    def __init__(
        self,
        *,
        data: typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["data", b"data"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["data", b"data"]
    ) -> None: ...

type___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    mime_type: google___ads___googleads___v4___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue = ...
    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...
    @property
    def file_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def full_size(self) -> type___ImageDimension: ...
    def __init__(
        self,
        *,
        data: typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
        file_size: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        mime_type: typing___Optional[
            google___ads___googleads___v4___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue
        ] = None,
        full_size: typing___Optional[type___ImageDimension] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "data", b"data", "file_size", b"file_size", "full_size", b"full_size"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...

type___ImageAsset = ImageAsset

class ImageDimension(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def height_pixels(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def width_pixels(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        height_pixels: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        width_pixels: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        url: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...

type___ImageDimension = ImageDimension

class TextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        text: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["text", b"text"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["text", b"text"]
    ) -> None: ...

type___TextAsset = TextAsset

class BookOnGoogleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___BookOnGoogleAsset = BookOnGoogleAsset



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListNumberRuleItemOperatorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListNumberRuleItemOperatorValue = typing___NewType(
        "UserListNumberRuleItemOperatorValue", builtin___int
    )
    type___UserListNumberRuleItemOperatorValue = UserListNumberRuleItemOperatorValue
    UserListNumberRuleItemOperator: _UserListNumberRuleItemOperator
    class _UserListNumberRuleItemOperator(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 0
        )
        UNKNOWN = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 1
        )
        GREATER_THAN = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 2
        )
        GREATER_THAN_OR_EQUAL = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 3
        )
        EQUALS = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 4
        )
        NOT_EQUALS = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 5
        )
        LESS_THAN = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 6
        )
        LESS_THAN_OR_EQUAL = typing___cast(
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 7
        )
    UNSPECIFIED = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 0
    )
    UNKNOWN = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 1
    )
    GREATER_THAN = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 2
    )
    GREATER_THAN_OR_EQUAL = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 3
    )
    EQUALS = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 4
    )
    NOT_EQUALS = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 5
    )
    LESS_THAN = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 6
    )
    LESS_THAN_OR_EQUAL = typing___cast(
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperatorValue, 7
    )
    type___UserListNumberRuleItemOperator = UserListNumberRuleItemOperator
    def __init__(self,) -> None: ...

type___UserListNumberRuleItemOperatorEnum = UserListNumberRuleItemOperatorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ClickTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ClickTypeValue = typing___NewType("ClickTypeValue", builtin___int)
    type___ClickTypeValue = ClickTypeValue
    ClickType: _ClickType
    class _ClickType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ClickTypeEnum.ClickTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ClickTypeEnum.ClickTypeValue, 0)
        UNKNOWN = typing___cast(ClickTypeEnum.ClickTypeValue, 1)
        APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 2)
        BREADCRUMBS = typing___cast(ClickTypeEnum.ClickTypeValue, 3)
        BROADBAND_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 4)
        CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 5)
        CALLS = typing___cast(ClickTypeEnum.ClickTypeValue, 6)
        CLICK_ON_ENGAGEMENT_AD = typing___cast(ClickTypeEnum.ClickTypeValue, 7)
        GET_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 8)
        LOCATION_EXPANSION = typing___cast(ClickTypeEnum.ClickTypeValue, 9)
        LOCATION_FORMAT_CALL = typing___cast(ClickTypeEnum.ClickTypeValue, 10)
        LOCATION_FORMAT_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 11)
        LOCATION_FORMAT_IMAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 12)
        LOCATION_FORMAT_LANDING_PAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 13)
        LOCATION_FORMAT_MAP = typing___cast(ClickTypeEnum.ClickTypeValue, 14)
        LOCATION_FORMAT_STORE_INFO = typing___cast(ClickTypeEnum.ClickTypeValue, 15)
        LOCATION_FORMAT_TEXT = typing___cast(ClickTypeEnum.ClickTypeValue, 16)
        MOBILE_CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 17)
        OFFER_PRINTS = typing___cast(ClickTypeEnum.ClickTypeValue, 18)
        OTHER = typing___cast(ClickTypeEnum.ClickTypeValue, 19)
        PRODUCT_EXTENSION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 20)
        PRODUCT_LISTING_AD_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 21)
        SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 22)
        STORE_LOCATOR = typing___cast(ClickTypeEnum.ClickTypeValue, 23)
        URL_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 25)
        VIDEO_APP_STORE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 26)
        VIDEO_CALL_TO_ACTION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 27)
        VIDEO_CARD_ACTION_HEADLINE_CLICKS = typing___cast(
            ClickTypeEnum.ClickTypeValue, 28
        )
        VIDEO_END_CAP_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 29)
        VIDEO_WEBSITE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 30)
        VISUAL_SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 31)
        WIRELESS_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 32)
        PRODUCT_LISTING_AD_LOCAL = typing___cast(ClickTypeEnum.ClickTypeValue, 33)
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = typing___cast(
            ClickTypeEnum.ClickTypeValue, 34
        )
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 35
        )
        PRODUCT_LISTING_ADS_COUPON = typing___cast(ClickTypeEnum.ClickTypeValue, 36)
        PRODUCT_LISTING_AD_TRANSACTABLE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 37
        )
        PRODUCT_AD_APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 38)
        SHOWCASE_AD_CATEGORY_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 39)
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK = typing___cast(
            ClickTypeEnum.ClickTypeValue, 40
        )
        SHOWCASE_AD_ONLINE_PRODUCT_LINK = typing___cast(
            ClickTypeEnum.ClickTypeValue, 42
        )
        SHOWCASE_AD_LOCAL_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 43)
        PROMOTION_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 44)
        SWIPEABLE_GALLERY_AD_HEADLINE = typing___cast(ClickTypeEnum.ClickTypeValue, 45)
        SWIPEABLE_GALLERY_AD_SWIPES = typing___cast(ClickTypeEnum.ClickTypeValue, 46)
        SWIPEABLE_GALLERY_AD_SEE_MORE = typing___cast(ClickTypeEnum.ClickTypeValue, 47)
        SWIPEABLE_GALLERY_AD_SITELINK_ONE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 48
        )
        SWIPEABLE_GALLERY_AD_SITELINK_TWO = typing___cast(
            ClickTypeEnum.ClickTypeValue, 49
        )
        SWIPEABLE_GALLERY_AD_SITELINK_THREE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 50
        )
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR = typing___cast(
            ClickTypeEnum.ClickTypeValue, 51
        )
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE = typing___cast(
            ClickTypeEnum.ClickTypeValue, 52
        )
        HOTEL_PRICE = typing___cast(ClickTypeEnum.ClickTypeValue, 53)
        PRICE_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 54)
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = typing___cast(
            ClickTypeEnum.ClickTypeValue, 55
        )
        SHOPPING_COMPARISON_LISTING = typing___cast(ClickTypeEnum.ClickTypeValue, 56)
    UNSPECIFIED = typing___cast(ClickTypeEnum.ClickTypeValue, 0)
    UNKNOWN = typing___cast(ClickTypeEnum.ClickTypeValue, 1)
    APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 2)
    BREADCRUMBS = typing___cast(ClickTypeEnum.ClickTypeValue, 3)
    BROADBAND_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 4)
    CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 5)
    CALLS = typing___cast(ClickTypeEnum.ClickTypeValue, 6)
    CLICK_ON_ENGAGEMENT_AD = typing___cast(ClickTypeEnum.ClickTypeValue, 7)
    GET_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 8)
    LOCATION_EXPANSION = typing___cast(ClickTypeEnum.ClickTypeValue, 9)
    LOCATION_FORMAT_CALL = typing___cast(ClickTypeEnum.ClickTypeValue, 10)
    LOCATION_FORMAT_DIRECTIONS = typing___cast(ClickTypeEnum.ClickTypeValue, 11)
    LOCATION_FORMAT_IMAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 12)
    LOCATION_FORMAT_LANDING_PAGE = typing___cast(ClickTypeEnum.ClickTypeValue, 13)
    LOCATION_FORMAT_MAP = typing___cast(ClickTypeEnum.ClickTypeValue, 14)
    LOCATION_FORMAT_STORE_INFO = typing___cast(ClickTypeEnum.ClickTypeValue, 15)
    LOCATION_FORMAT_TEXT = typing___cast(ClickTypeEnum.ClickTypeValue, 16)
    MOBILE_CALL_TRACKING = typing___cast(ClickTypeEnum.ClickTypeValue, 17)
    OFFER_PRINTS = typing___cast(ClickTypeEnum.ClickTypeValue, 18)
    OTHER = typing___cast(ClickTypeEnum.ClickTypeValue, 19)
    PRODUCT_EXTENSION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 20)
    PRODUCT_LISTING_AD_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 21)
    SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 22)
    STORE_LOCATOR = typing___cast(ClickTypeEnum.ClickTypeValue, 23)
    URL_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 25)
    VIDEO_APP_STORE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 26)
    VIDEO_CALL_TO_ACTION_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 27)
    VIDEO_CARD_ACTION_HEADLINE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 28)
    VIDEO_END_CAP_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 29)
    VIDEO_WEBSITE_CLICKS = typing___cast(ClickTypeEnum.ClickTypeValue, 30)
    VISUAL_SITELINKS = typing___cast(ClickTypeEnum.ClickTypeValue, 31)
    WIRELESS_PLAN = typing___cast(ClickTypeEnum.ClickTypeValue, 32)
    PRODUCT_LISTING_AD_LOCAL = typing___cast(ClickTypeEnum.ClickTypeValue, 33)
    PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = typing___cast(
        ClickTypeEnum.ClickTypeValue, 34
    )
    PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = typing___cast(
        ClickTypeEnum.ClickTypeValue, 35
    )
    PRODUCT_LISTING_ADS_COUPON = typing___cast(ClickTypeEnum.ClickTypeValue, 36)
    PRODUCT_LISTING_AD_TRANSACTABLE = typing___cast(ClickTypeEnum.ClickTypeValue, 37)
    PRODUCT_AD_APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickTypeValue, 38)
    SHOWCASE_AD_CATEGORY_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 39)
    SHOWCASE_AD_LOCAL_STOREFRONT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 40)
    SHOWCASE_AD_ONLINE_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 42)
    SHOWCASE_AD_LOCAL_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickTypeValue, 43)
    PROMOTION_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 44)
    SWIPEABLE_GALLERY_AD_HEADLINE = typing___cast(ClickTypeEnum.ClickTypeValue, 45)
    SWIPEABLE_GALLERY_AD_SWIPES = typing___cast(ClickTypeEnum.ClickTypeValue, 46)
    SWIPEABLE_GALLERY_AD_SEE_MORE = typing___cast(ClickTypeEnum.ClickTypeValue, 47)
    SWIPEABLE_GALLERY_AD_SITELINK_ONE = typing___cast(ClickTypeEnum.ClickTypeValue, 48)
    SWIPEABLE_GALLERY_AD_SITELINK_TWO = typing___cast(ClickTypeEnum.ClickTypeValue, 49)
    SWIPEABLE_GALLERY_AD_SITELINK_THREE = typing___cast(
        ClickTypeEnum.ClickTypeValue, 50
    )
    SWIPEABLE_GALLERY_AD_SITELINK_FOUR = typing___cast(ClickTypeEnum.ClickTypeValue, 51)
    SWIPEABLE_GALLERY_AD_SITELINK_FIVE = typing___cast(ClickTypeEnum.ClickTypeValue, 52)
    HOTEL_PRICE = typing___cast(ClickTypeEnum.ClickTypeValue, 53)
    PRICE_EXTENSION = typing___cast(ClickTypeEnum.ClickTypeValue, 54)
    HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = typing___cast(
        ClickTypeEnum.ClickTypeValue, 55
    )
    SHOPPING_COMPARISON_LISTING = typing___cast(ClickTypeEnum.ClickTypeValue, 56)
    type___ClickType = ClickType
    def __init__(self,) -> None: ...

type___ClickTypeEnum = ClickTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.lead_form_call_to_action_type_pb2 import (
    LeadFormCallToActionTypeEnum as google___ads___googleads___v6___enums___lead_form_call_to_action_type_pb2___LeadFormCallToActionTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.lead_form_desired_intent_pb2 import (
    LeadFormDesiredIntentEnum as google___ads___googleads___v6___enums___lead_form_desired_intent_pb2___LeadFormDesiredIntentEnum,
)
from google.ads.google_ads.v6.proto.enums.lead_form_field_user_input_type_pb2 import (
    LeadFormFieldUserInputTypeEnum as google___ads___googleads___v6___enums___lead_form_field_user_input_type_pb2___LeadFormFieldUserInputTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.lead_form_post_submit_call_to_action_type_pb2 import (
    LeadFormPostSubmitCallToActionTypeEnum as google___ads___googleads___v6___enums___lead_form_post_submit_call_to_action_type_pb2___LeadFormPostSubmitCallToActionTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v6___enums___mime_type_pb2___MimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class YoutubeVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    youtube_video_id: typing___Text = ...
    def __init__(
        self, *, youtube_video_id: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_youtube_video_id", b"_youtube_video_id"
        ],
    ) -> typing_extensions___Literal["youtube_video_id"]: ...

type___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___bytes = ...
    def __init__(self, *, data: typing___Optional[builtin___bytes] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_data", b"_data", "data", b"data"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_data", b"_data", "data", b"data"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_data", b"_data"]
    ) -> typing_extensions___Literal["data"]: ...

type___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___bytes = ...
    file_size: builtin___int = ...
    mime_type: google___ads___googleads___v6___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue = ...
    @property
    def full_size(self) -> type___ImageDimension: ...
    def __init__(
        self,
        *,
        data: typing___Optional[builtin___bytes] = None,
        file_size: typing___Optional[builtin___int] = None,
        mime_type: typing___Optional[
            google___ads___googleads___v6___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue
        ] = None,
        full_size: typing___Optional[type___ImageDimension] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_data", b"_data"]
    ) -> typing_extensions___Literal["data"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_file_size", b"_file_size"]
    ) -> typing_extensions___Literal["file_size"]: ...

type___ImageAsset = ImageAsset

class ImageDimension(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    height_pixels: builtin___int = ...
    width_pixels: builtin___int = ...
    url: typing___Text = ...
    def __init__(
        self,
        *,
        height_pixels: typing___Optional[builtin___int] = None,
        width_pixels: typing___Optional[builtin___int] = None,
        url: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_height_pixels", b"_height_pixels"],
    ) -> typing_extensions___Literal["height_pixels"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_url", b"_url"]
    ) -> typing_extensions___Literal["url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_width_pixels", b"_width_pixels"],
    ) -> typing_extensions___Literal["width_pixels"]: ...

type___ImageDimension = ImageDimension

class TextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    text: typing___Text = ...
    def __init__(self, *, text: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_text", b"_text", "text", b"text"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_text", b"_text", "text", b"text"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text", b"_text"]
    ) -> typing_extensions___Literal["text"]: ...

type___TextAsset = TextAsset

class LeadFormAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    business_name: typing___Text = ...
    call_to_action_type: google___ads___googleads___v6___enums___lead_form_call_to_action_type_pb2___LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue = ...
    call_to_action_description: typing___Text = ...
    headline: typing___Text = ...
    description: typing___Text = ...
    privacy_policy_url: typing___Text = ...
    post_submit_headline: typing___Text = ...
    post_submit_description: typing___Text = ...
    post_submit_call_to_action_type: google___ads___googleads___v6___enums___lead_form_post_submit_call_to_action_type_pb2___LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue = ...
    background_image_asset: typing___Text = ...
    desired_intent: google___ads___googleads___v6___enums___lead_form_desired_intent_pb2___LeadFormDesiredIntentEnum.LeadFormDesiredIntentValue = ...
    custom_disclosure: typing___Text = ...
    @property
    def fields(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___LeadFormField
    ]: ...
    @property
    def delivery_methods(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___LeadFormDeliveryMethod
    ]: ...
    def __init__(
        self,
        *,
        business_name: typing___Optional[typing___Text] = None,
        call_to_action_type: typing___Optional[
            google___ads___googleads___v6___enums___lead_form_call_to_action_type_pb2___LeadFormCallToActionTypeEnum.LeadFormCallToActionTypeValue
        ] = None,
        call_to_action_description: typing___Optional[typing___Text] = None,
        headline: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
        privacy_policy_url: typing___Optional[typing___Text] = None,
        post_submit_headline: typing___Optional[typing___Text] = None,
        post_submit_description: typing___Optional[typing___Text] = None,
        fields: typing___Optional[typing___Iterable[type___LeadFormField]] = None,
        delivery_methods: typing___Optional[
            typing___Iterable[type___LeadFormDeliveryMethod]
        ] = None,
        post_submit_call_to_action_type: typing___Optional[
            google___ads___googleads___v6___enums___lead_form_post_submit_call_to_action_type_pb2___LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue
        ] = None,
        background_image_asset: typing___Optional[typing___Text] = None,
        desired_intent: typing___Optional[
            google___ads___googleads___v6___enums___lead_form_desired_intent_pb2___LeadFormDesiredIntentEnum.LeadFormDesiredIntentValue
        ] = None,
        custom_disclosure: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_background_image_asset",
            b"_background_image_asset",
            "_custom_disclosure",
            b"_custom_disclosure",
            "_post_submit_description",
            b"_post_submit_description",
            "_post_submit_headline",
            b"_post_submit_headline",
            "background_image_asset",
            b"background_image_asset",
            "custom_disclosure",
            b"custom_disclosure",
            "post_submit_description",
            b"post_submit_description",
            "post_submit_headline",
            b"post_submit_headline",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_background_image_asset",
            b"_background_image_asset",
            "_custom_disclosure",
            b"_custom_disclosure",
            "_post_submit_description",
            b"_post_submit_description",
            "_post_submit_headline",
            b"_post_submit_headline",
            "background_image_asset",
            b"background_image_asset",
            "business_name",
            b"business_name",
            "call_to_action_description",
            b"call_to_action_description",
            "call_to_action_type",
            b"call_to_action_type",
            "custom_disclosure",
            b"custom_disclosure",
            "delivery_methods",
            b"delivery_methods",
            "description",
            b"description",
            "desired_intent",
            b"desired_intent",
            "fields",
            b"fields",
            "headline",
            b"headline",
            "post_submit_call_to_action_type",
            b"post_submit_call_to_action_type",
            "post_submit_description",
            b"post_submit_description",
            "post_submit_headline",
            b"post_submit_headline",
            "privacy_policy_url",
            b"privacy_policy_url",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_background_image_asset", b"_background_image_asset"
        ],
    ) -> typing_extensions___Literal["background_image_asset"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_custom_disclosure", b"_custom_disclosure"
        ],
    ) -> typing_extensions___Literal["custom_disclosure"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_post_submit_description", b"_post_submit_description"
        ],
    ) -> typing_extensions___Literal["post_submit_description"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_post_submit_headline", b"_post_submit_headline"
        ],
    ) -> typing_extensions___Literal["post_submit_headline"]: ...

type___LeadFormAsset = LeadFormAsset

class LeadFormField(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    input_type: google___ads___googleads___v6___enums___lead_form_field_user_input_type_pb2___LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue = ...
    @property
    def single_choice_answers(self) -> type___LeadFormSingleChoiceAnswers: ...
    def __init__(
        self,
        *,
        input_type: typing___Optional[
            google___ads___googleads___v6___enums___lead_form_field_user_input_type_pb2___LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue
        ] = None,
        single_choice_answers: typing___Optional[
            type___LeadFormSingleChoiceAnswers
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "answers", b"answers", "single_choice_answers", b"single_choice_answers"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "answers",
            b"answers",
            "input_type",
            b"input_type",
            "single_choice_answers",
            b"single_choice_answers",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["answers", b"answers"]
    ) -> typing_extensions___Literal["single_choice_answers"]: ...

type___LeadFormField = LeadFormField

class LeadFormSingleChoiceAnswers(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    answers: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    def __init__(
        self, *, answers: typing___Optional[typing___Iterable[typing___Text]] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["answers", b"answers"]
    ) -> None: ...

type___LeadFormSingleChoiceAnswers = LeadFormSingleChoiceAnswers

class LeadFormDeliveryMethod(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def webhook(self) -> type___WebhookDelivery: ...
    def __init__(
        self, *, webhook: typing___Optional[type___WebhookDelivery] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "delivery_details", b"delivery_details", "webhook", b"webhook"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "delivery_details", b"delivery_details", "webhook", b"webhook"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "delivery_details", b"delivery_details"
        ],
    ) -> typing_extensions___Literal["webhook"]: ...

type___LeadFormDeliveryMethod = LeadFormDeliveryMethod

class WebhookDelivery(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    advertiser_webhook_url: typing___Text = ...
    google_secret: typing___Text = ...
    payload_schema_version: builtin___int = ...
    def __init__(
        self,
        *,
        advertiser_webhook_url: typing___Optional[typing___Text] = None,
        google_secret: typing___Optional[typing___Text] = None,
        payload_schema_version: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_advertiser_webhook_url",
            b"_advertiser_webhook_url",
            "_google_secret",
            b"_google_secret",
            "_payload_schema_version",
            b"_payload_schema_version",
            "advertiser_webhook_url",
            b"advertiser_webhook_url",
            "google_secret",
            b"google_secret",
            "payload_schema_version",
            b"payload_schema_version",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_advertiser_webhook_url",
            b"_advertiser_webhook_url",
            "_google_secret",
            b"_google_secret",
            "_payload_schema_version",
            b"_payload_schema_version",
            "advertiser_webhook_url",
            b"advertiser_webhook_url",
            "google_secret",
            b"google_secret",
            "payload_schema_version",
            b"payload_schema_version",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_advertiser_webhook_url", b"_advertiser_webhook_url"
        ],
    ) -> typing_extensions___Literal["advertiser_webhook_url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_google_secret", b"_google_secret"],
    ) -> typing_extensions___Literal["google_secret"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_payload_schema_version", b"_payload_schema_version"
        ],
    ) -> typing_extensions___Literal["payload_schema_version"]: ...

type___WebhookDelivery = WebhookDelivery

class BookOnGoogleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___BookOnGoogleAsset = BookOnGoogleAsset



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2 import (
    DynamicAffiliateLocationSetFilter as google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicAffiliateLocationSetFilter,
    DynamicLocationSetFilter as google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicLocationSetFilter,
)
from google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2 import (
    FeedItemSetStatusEnum as google___ads___googleads___v6___enums___feed_item_set_status_pb2___FeedItemSetStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemSet(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    feed: typing___Text = ...
    feed_item_set_id: builtin___int = ...
    display_name: typing___Text = ...
    status: google___ads___googleads___v6___enums___feed_item_set_status_pb2___FeedItemSetStatusEnum.FeedItemSetStatusValue = ...
    @property
    def dynamic_location_set_filter(
        self,
    ) -> google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicLocationSetFilter: ...
    @property
    def dynamic_affiliate_location_set_filter(
        self,
    ) -> google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicAffiliateLocationSetFilter: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed: typing___Optional[typing___Text] = None,
        feed_item_set_id: typing___Optional[builtin___int] = None,
        display_name: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_set_status_pb2___FeedItemSetStatusEnum.FeedItemSetStatusValue
        ] = None,
        dynamic_location_set_filter: typing___Optional[
            google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicLocationSetFilter
        ] = None,
        dynamic_affiliate_location_set_filter: typing___Optional[
            google___ads___googleads___v6___common___feed_item_set_filter_type_infos_pb2___DynamicAffiliateLocationSetFilter
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "display_name",
            b"display_name",
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
            "feed",
            b"feed",
            "feed_item_set_id",
            b"feed_item_set_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "dynamic_set_filter", b"dynamic_set_filter"
        ],
    ) -> typing_extensions___Literal[
        "dynamic_location_set_filter", "dynamic_affiliate_location_set_filter"
    ]: ...

type___FeedItemSet = FeedItemSet



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class WebpageConditionOperandEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    WebpageConditionOperandValue = typing___NewType(
        "WebpageConditionOperandValue", builtin___int
    )
    type___WebpageConditionOperandValue = WebpageConditionOperandValue
    WebpageConditionOperand: _WebpageConditionOperand
    class _WebpageConditionOperand(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            WebpageConditionOperandEnum.WebpageConditionOperandValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 0
        )
        UNKNOWN = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 1
        )
        URL = typing___cast(WebpageConditionOperandEnum.WebpageConditionOperandValue, 2)
        CATEGORY = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 3
        )
        PAGE_TITLE = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 4
        )
        PAGE_CONTENT = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 5
        )
        CUSTOM_LABEL = typing___cast(
            WebpageConditionOperandEnum.WebpageConditionOperandValue, 6
        )
    UNSPECIFIED = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 0
    )
    UNKNOWN = typing___cast(WebpageConditionOperandEnum.WebpageConditionOperandValue, 1)
    URL = typing___cast(WebpageConditionOperandEnum.WebpageConditionOperandValue, 2)
    CATEGORY = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 3
    )
    PAGE_TITLE = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 4
    )
    PAGE_CONTENT = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 5
    )
    CUSTOM_LABEL = typing___cast(
        WebpageConditionOperandEnum.WebpageConditionOperandValue, 6
    )
    type___WebpageConditionOperand = WebpageConditionOperand
    def __init__(self,) -> None: ...

type___WebpageConditionOperandEnum = WebpageConditionOperandEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UploadClickConversionsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    validate_only: builtin___bool = ...
    @property
    def conversions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ClickConversion
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        conversions: typing___Optional[
            typing___Iterable[type___ClickConversion]
        ] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversions",
            b"conversions",
            "customer_id",
            b"customer_id",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___UploadClickConversionsRequest = UploadClickConversionsRequest

class UploadClickConversionsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ClickConversionResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
        results: typing___Optional[
            typing___Iterable[type___ClickConversionResult]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

type___UploadClickConversionsResponse = UploadClickConversionsResponse

class UploadCallConversionsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    validate_only: builtin___bool = ...
    @property
    def conversions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CallConversion
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        conversions: typing___Optional[typing___Iterable[type___CallConversion]] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversions",
            b"conversions",
            "customer_id",
            b"customer_id",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___UploadCallConversionsRequest = UploadCallConversionsRequest

class UploadCallConversionsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CallConversionResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
        results: typing___Optional[
            typing___Iterable[type___CallConversionResult]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

type___UploadCallConversionsResponse = UploadCallConversionsResponse

class ClickConversion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def gclid(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def order_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def external_attribution_data(self) -> type___ExternalAttributionData: ...
    def __init__(
        self,
        *,
        gclid: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_action: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_value: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        order_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        external_attribution_data: typing___Optional[
            type___ExternalAttributionData
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
            "external_attribution_data",
            b"external_attribution_data",
            "gclid",
            b"gclid",
            "order_id",
            b"order_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
            "external_attribution_data",
            b"external_attribution_data",
            "gclid",
            b"gclid",
            "order_id",
            b"order_id",
        ],
    ) -> None: ...

type___ClickConversion = ClickConversion

class CallConversion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def caller_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def call_start_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        caller_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        call_start_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_action: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_value: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> None: ...

type___CallConversion = CallConversion

class ExternalAttributionData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def external_attribution_credit(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def external_attribution_model(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        external_attribution_credit: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        external_attribution_model: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "external_attribution_credit",
            b"external_attribution_credit",
            "external_attribution_model",
            b"external_attribution_model",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "external_attribution_credit",
            b"external_attribution_credit",
            "external_attribution_model",
            b"external_attribution_model",
        ],
    ) -> None: ...

type___ExternalAttributionData = ExternalAttributionData

class ClickConversionResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def gclid(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        gclid: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_action: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> None: ...

type___ClickConversionResult = ClickConversionResult

class CallConversionResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def caller_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def call_start_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conversion_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        caller_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        call_start_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_action: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conversion_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
        ],
    ) -> None: ...

type___CallConversionResult = CallConversionResult



from typing import Any

class AdGroupSimulationServiceStub:
    GetAdGroupSimulation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupSimulationServiceServicer:
    def GetAdGroupSimulation(self, request: Any, context: Any) -> None: ...

def add_AdGroupSimulationServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FunctionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FunctionErrorValue = typing___NewType("FunctionErrorValue", builtin___int)
    type___FunctionErrorValue = FunctionErrorValue
    FunctionError: _FunctionError
    class _FunctionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FunctionErrorEnum.FunctionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FunctionErrorEnum.FunctionErrorValue, 0)
        UNKNOWN = typing___cast(FunctionErrorEnum.FunctionErrorValue, 1)
        INVALID_FUNCTION_FORMAT = typing___cast(FunctionErrorEnum.FunctionErrorValue, 2)
        DATA_TYPE_MISMATCH = typing___cast(FunctionErrorEnum.FunctionErrorValue, 3)
        INVALID_CONJUNCTION_OPERANDS = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 4
        )
        INVALID_NUMBER_OF_OPERANDS = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 5
        )
        INVALID_OPERAND_TYPE = typing___cast(FunctionErrorEnum.FunctionErrorValue, 6)
        INVALID_OPERATOR = typing___cast(FunctionErrorEnum.FunctionErrorValue, 7)
        INVALID_REQUEST_CONTEXT_TYPE = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 8
        )
        INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 9
        )
        INVALID_FUNCTION_FOR_PLACEHOLDER = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 10
        )
        INVALID_OPERAND = typing___cast(FunctionErrorEnum.FunctionErrorValue, 11)
        MISSING_CONSTANT_OPERAND_VALUE = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 12
        )
        INVALID_CONSTANT_OPERAND_VALUE = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 13
        )
        INVALID_NESTING = typing___cast(FunctionErrorEnum.FunctionErrorValue, 14)
        MULTIPLE_FEED_IDS_NOT_SUPPORTED = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 15
        )
        INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = typing___cast(
            FunctionErrorEnum.FunctionErrorValue, 16
        )
        INVALID_ATTRIBUTE_NAME = typing___cast(FunctionErrorEnum.FunctionErrorValue, 17)
    UNSPECIFIED = typing___cast(FunctionErrorEnum.FunctionErrorValue, 0)
    UNKNOWN = typing___cast(FunctionErrorEnum.FunctionErrorValue, 1)
    INVALID_FUNCTION_FORMAT = typing___cast(FunctionErrorEnum.FunctionErrorValue, 2)
    DATA_TYPE_MISMATCH = typing___cast(FunctionErrorEnum.FunctionErrorValue, 3)
    INVALID_CONJUNCTION_OPERANDS = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 4
    )
    INVALID_NUMBER_OF_OPERANDS = typing___cast(FunctionErrorEnum.FunctionErrorValue, 5)
    INVALID_OPERAND_TYPE = typing___cast(FunctionErrorEnum.FunctionErrorValue, 6)
    INVALID_OPERATOR = typing___cast(FunctionErrorEnum.FunctionErrorValue, 7)
    INVALID_REQUEST_CONTEXT_TYPE = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 8
    )
    INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 9
    )
    INVALID_FUNCTION_FOR_PLACEHOLDER = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 10
    )
    INVALID_OPERAND = typing___cast(FunctionErrorEnum.FunctionErrorValue, 11)
    MISSING_CONSTANT_OPERAND_VALUE = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 12
    )
    INVALID_CONSTANT_OPERAND_VALUE = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 13
    )
    INVALID_NESTING = typing___cast(FunctionErrorEnum.FunctionErrorValue, 14)
    MULTIPLE_FEED_IDS_NOT_SUPPORTED = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 15
    )
    INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = typing___cast(
        FunctionErrorEnum.FunctionErrorValue, 16
    )
    INVALID_ATTRIBUTE_NAME = typing___cast(FunctionErrorEnum.FunctionErrorValue, 17)
    type___FunctionError = FunctionError
    def __init__(self,) -> None: ...

type___FunctionErrorEnum = FunctionErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ChangeStatusResourceTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ChangeStatusResourceTypeValue = typing___NewType(
        "ChangeStatusResourceTypeValue", builtin___int
    )
    type___ChangeStatusResourceTypeValue = ChangeStatusResourceTypeValue
    ChangeStatusResourceType: _ChangeStatusResourceType
    class _ChangeStatusResourceType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 0
        )
        UNKNOWN = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 1
        )
        AD_GROUP = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 3
        )
        AD_GROUP_AD = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 4
        )
        AD_GROUP_CRITERION = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 5
        )
        CAMPAIGN = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 6
        )
        CAMPAIGN_CRITERION = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 7
        )
        FEED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 9
        )
        FEED_ITEM = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 10
        )
        AD_GROUP_FEED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 11
        )
        CAMPAIGN_FEED = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 12
        )
        AD_GROUP_BID_MODIFIER = typing___cast(
            ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 13
        )
    UNSPECIFIED = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 0
    )
    UNKNOWN = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 1
    )
    AD_GROUP = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 3
    )
    AD_GROUP_AD = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 4
    )
    AD_GROUP_CRITERION = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 5
    )
    CAMPAIGN = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 6
    )
    CAMPAIGN_CRITERION = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 7
    )
    FEED = typing___cast(ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 9)
    FEED_ITEM = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 10
    )
    AD_GROUP_FEED = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 11
    )
    CAMPAIGN_FEED = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 12
    )
    AD_GROUP_BID_MODIFIER = typing___cast(
        ChangeStatusResourceTypeEnum.ChangeStatusResourceTypeValue, 13
    )
    type___ChangeStatusResourceType = ChangeStatusResourceType
    def __init__(self,) -> None: ...

type___ChangeStatusResourceTypeEnum = ChangeStatusResourceTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GoogleAdsFieldCategoryEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    GoogleAdsFieldCategoryValue = typing___NewType(
        "GoogleAdsFieldCategoryValue", builtin___int
    )
    type___GoogleAdsFieldCategoryValue = GoogleAdsFieldCategoryValue
    GoogleAdsFieldCategory: _GoogleAdsFieldCategory
    class _GoogleAdsFieldCategory(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 0
        )
        UNKNOWN = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 1
        )
        RESOURCE = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 2
        )
        ATTRIBUTE = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 3
        )
        SEGMENT = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 5
        )
        METRIC = typing___cast(
            GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 6
        )
    UNSPECIFIED = typing___cast(
        GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 0
    )
    UNKNOWN = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 1)
    RESOURCE = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 2)
    ATTRIBUTE = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 3)
    SEGMENT = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 5)
    METRIC = typing___cast(GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategoryValue, 6)
    type___GoogleAdsFieldCategory = GoogleAdsFieldCategory
    def __init__(self,) -> None: ...

type___GoogleAdsFieldCategoryEnum = GoogleAdsFieldCategoryEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2 import (
    CustomerPayPerConversionEligibilityFailureReasonEnum as google___ads___googleads___v3___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Customer(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    pay_per_conversion_eligibility_failure_reasons: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v3___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue
    ] = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def descriptive_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def time_zone(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def auto_tagging_enabled(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def has_partners_badge(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def manager(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def test_account(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def call_reporting_setting(self) -> type___CallReportingSetting: ...
    @property
    def conversion_tracking_setting(self) -> type___ConversionTrackingSetting: ...
    @property
    def remarketing_setting(self) -> type___RemarketingSetting: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        descriptive_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        time_zone: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        auto_tagging_enabled: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        has_partners_badge: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        manager: typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        test_account: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        call_reporting_setting: typing___Optional[type___CallReportingSetting] = None,
        conversion_tracking_setting: typing___Optional[
            type___ConversionTrackingSetting
        ] = None,
        remarketing_setting: typing___Optional[type___RemarketingSetting] = None,
        pay_per_conversion_eligibility_failure_reasons: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue
            ]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "auto_tagging_enabled",
            b"auto_tagging_enabled",
            "call_reporting_setting",
            b"call_reporting_setting",
            "conversion_tracking_setting",
            b"conversion_tracking_setting",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "final_url_suffix",
            b"final_url_suffix",
            "has_partners_badge",
            b"has_partners_badge",
            "id",
            b"id",
            "manager",
            b"manager",
            "remarketing_setting",
            b"remarketing_setting",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "auto_tagging_enabled",
            b"auto_tagging_enabled",
            "call_reporting_setting",
            b"call_reporting_setting",
            "conversion_tracking_setting",
            b"conversion_tracking_setting",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "final_url_suffix",
            b"final_url_suffix",
            "has_partners_badge",
            b"has_partners_badge",
            "id",
            b"id",
            "manager",
            b"manager",
            "pay_per_conversion_eligibility_failure_reasons",
            b"pay_per_conversion_eligibility_failure_reasons",
            "remarketing_setting",
            b"remarketing_setting",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> None: ...

type___Customer = Customer

class CallReportingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def call_reporting_enabled(
        self,
    ) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def call_conversion_reporting_enabled(
        self,
    ) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def call_conversion_action(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        call_reporting_enabled: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        call_conversion_reporting_enabled: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        call_conversion_action: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_enabled",
            b"call_conversion_reporting_enabled",
            "call_reporting_enabled",
            b"call_reporting_enabled",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_enabled",
            b"call_conversion_reporting_enabled",
            "call_reporting_enabled",
            b"call_reporting_enabled",
        ],
    ) -> None: ...

type___CallReportingSetting = CallReportingSetting

class ConversionTrackingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def conversion_tracking_id(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def cross_account_conversion_tracking_id(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        conversion_tracking_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        cross_account_conversion_tracking_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_tracking_id",
            b"conversion_tracking_id",
            "cross_account_conversion_tracking_id",
            b"cross_account_conversion_tracking_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conversion_tracking_id",
            b"conversion_tracking_id",
            "cross_account_conversion_tracking_id",
            b"cross_account_conversion_tracking_id",
        ],
    ) -> None: ...

type___ConversionTrackingSetting = ConversionTrackingSetting

class RemarketingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def google_global_site_tag(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        google_global_site_tag: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "google_global_site_tag", b"google_global_site_tag"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "google_global_site_tag", b"google_global_site_tag"
        ],
    ) -> None: ...

type___RemarketingSetting = RemarketingSetting



from typing import Any

class AdGroupCriterionLabelServiceStub:
    GetAdGroupCriterionLabel: Any = ...
    MutateAdGroupCriterionLabels: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupCriterionLabelServiceServicer:
    def GetAdGroupCriterionLabel(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupCriterionLabels(self, request: Any, context: Any) -> None: ...

def add_AdGroupCriterionLabelServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MediaTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MediaTypeValue = typing___NewType("MediaTypeValue", builtin___int)
    type___MediaTypeValue = MediaTypeValue
    MediaType: _MediaType
    class _MediaType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MediaTypeEnum.MediaTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MediaTypeEnum.MediaTypeValue, 0)
        UNKNOWN = typing___cast(MediaTypeEnum.MediaTypeValue, 1)
        IMAGE = typing___cast(MediaTypeEnum.MediaTypeValue, 2)
        ICON = typing___cast(MediaTypeEnum.MediaTypeValue, 3)
        MEDIA_BUNDLE = typing___cast(MediaTypeEnum.MediaTypeValue, 4)
        AUDIO = typing___cast(MediaTypeEnum.MediaTypeValue, 5)
        VIDEO = typing___cast(MediaTypeEnum.MediaTypeValue, 6)
        DYNAMIC_IMAGE = typing___cast(MediaTypeEnum.MediaTypeValue, 7)
    UNSPECIFIED = typing___cast(MediaTypeEnum.MediaTypeValue, 0)
    UNKNOWN = typing___cast(MediaTypeEnum.MediaTypeValue, 1)
    IMAGE = typing___cast(MediaTypeEnum.MediaTypeValue, 2)
    ICON = typing___cast(MediaTypeEnum.MediaTypeValue, 3)
    MEDIA_BUNDLE = typing___cast(MediaTypeEnum.MediaTypeValue, 4)
    AUDIO = typing___cast(MediaTypeEnum.MediaTypeValue, 5)
    VIDEO = typing___cast(MediaTypeEnum.MediaTypeValue, 6)
    DYNAMIC_IMAGE = typing___cast(MediaTypeEnum.MediaTypeValue, 7)
    type___MediaType = MediaType
    def __init__(self,) -> None: ...

type___MediaTypeEnum = MediaTypeEnum



from typing import Any, Optional

class KeywordPlanServiceStub:
    GetKeywordPlan: Any = ...
    MutateKeywordPlans: Any = ...
    GenerateForecastCurve: Any = ...
    GenerateForecastTimeSeries: Any = ...
    GenerateForecastMetrics: Any = ...
    GenerateHistoricalMetrics: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanServiceServicer:
    def GetKeywordPlan(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlans(self, request: Any, context: Any) -> None: ...
    def GenerateForecastCurve(self, request: Any, context: Any) -> None: ...
    def GenerateForecastTimeSeries(self, request: Any, context: Any) -> None: ...
    def GenerateForecastMetrics(self, request: Any, context: Any) -> None: ...
    def GenerateHistoricalMetrics(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanServiceServicer_to_server(servicer: Any, server: Any) -> None: ...

class KeywordPlanService:
    @staticmethod
    def GetKeywordPlan(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateKeywordPlans(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def GenerateForecastCurve(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def GenerateForecastTimeSeries(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def GenerateForecastMetrics(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def GenerateHistoricalMetrics(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



from typing import Any

class BillingSetupServiceStub:
    GetBillingSetup: Any = ...
    MutateBillingSetup: Any = ...
    def __init__(self, channel: Any) -> None: ...

class BillingSetupServiceServicer:
    def GetBillingSetup(self, request: Any, context: Any) -> None: ...
    def MutateBillingSetup(self, request: Any, context: Any) -> None: ...

def add_BillingSetupServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignBudgetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignBudgetErrorValue = typing___NewType(
        "CampaignBudgetErrorValue", builtin___int
    )
    type___CampaignBudgetErrorValue = CampaignBudgetErrorValue
    CampaignBudgetError: _CampaignBudgetError
    class _CampaignBudgetError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 0)
        UNKNOWN = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 1)
        CAMPAIGN_BUDGET_CANNOT_BE_SHARED = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 17
        )
        CAMPAIGN_BUDGET_REMOVED = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 2
        )
        CAMPAIGN_BUDGET_IN_USE = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 3
        )
        CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 4
        )
        CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 6
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 7
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 8
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 9
        )
        CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 10
        )
        DUPLICATE_NAME = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 11
        )
        MONEY_AMOUNT_IN_WRONG_CURRENCY = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 12
        )
        MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 13
        )
        MONEY_AMOUNT_TOO_LARGE = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 14
        )
        NEGATIVE_MONEY_AMOUNT = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 15
        )
        NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 16
        )
        TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY = typing___cast(
            CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 18
        )
    UNSPECIFIED = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 0)
    UNKNOWN = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 1)
    CAMPAIGN_BUDGET_CANNOT_BE_SHARED = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 17
    )
    CAMPAIGN_BUDGET_REMOVED = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 2
    )
    CAMPAIGN_BUDGET_IN_USE = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 3
    )
    CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 4
    )
    CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 6
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 7
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 8
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 9
    )
    CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 10
    )
    DUPLICATE_NAME = typing___cast(CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 11)
    MONEY_AMOUNT_IN_WRONG_CURRENCY = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 12
    )
    MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 13
    )
    MONEY_AMOUNT_TOO_LARGE = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 14
    )
    NEGATIVE_MONEY_AMOUNT = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 15
    )
    NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 16
    )
    TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY = typing___cast(
        CampaignBudgetErrorEnum.CampaignBudgetErrorValue, 18
    )
    type___CampaignBudgetError = CampaignBudgetError
    def __init__(self,) -> None: ...

type___CampaignBudgetErrorEnum = CampaignBudgetErrorEnum
